from tejapi.model.datatable import Datatable
from tejapi.errors.tej_error import LimitExceededError
from .api_config import ApiConfig
from .message import Message
import warnings
import copy
import requests

def get(datatable_code, **options):
    detect_internal()
    if 'paginate' in options.keys():
        paginate = options.pop('paginate')
    else:
        paginate = None

    data = None
    page_count = 0
    while True:
        next_options = copy.deepcopy(options)
        next_data = Datatable(datatable_code).data(params=next_options)

        if data is None:
            data = next_data
        else:
            data.extend(next_data)

        if page_count >= ApiConfig.page_limit:
            raise LimitExceededError(
                Message.WARN_DATA_LIMIT_EXCEEDED % (datatable_code,
                                                    ApiConfig.api_key
                                                    )
            )

        next_cursor_id = next_data.meta['next_cursor_id']

        if next_cursor_id is None:
            break
        elif paginate is not True and next_cursor_id is not None:
            warnings.warn(Message.WARN_PAGE_LIMIT_EXCEEDED, UserWarning)
            break

        page_count = page_count + 1
        options['opts.cursor_id'] = next_cursor_id
    return data.to_pandas()

def detect_internal():
    if(ApiConfig.api_base=="https://api.tej.com.tw"):
        api_base = "http://10.10.10.66"
        try:
            r = requests.get(url=api_base+'/web/api').json()
            if(r['internal']):
                ApiConfig.api_base=api_base
        except:
            pass